@@ -208,8 +208,8 @@ target_unmarshal_value.tar_pattern <- function(target) {
 }
 
 #' @export
-target_produce_child.tar_pattern <- function(target, name) {
-  pattern_produce_branch(target, name)
+target_produce_child.tar_pattern <- function(target, name, index) {
+  pattern_produce_branch(target, name, index)
 }
 
 #' @export
@@ -264,9 +264,8 @@ pattern_prepend_branches <- function(target, scheduler) {
   scheduler$queue$prepend(children, ranks)
 }
 
-pattern_produce_branch <- function(target, name) {
+pattern_produce_branch <- function(target, name, index) {
   junction <- .subset2(target, "junction")
-  index <- junction_extract_index(junction, name)
   deps_child <- junction_extract_deps(junction, index)
   branch_init(
     name = name,
@@ -349,6 +348,7 @@ pattern_begin_initial <- function(target, pipeline, scheduler, meta) {
   pattern_requeue_downstream_branching(target, pipeline, scheduler)
   pattern_requeue_self(target, scheduler)
   pattern_insert_branches(target, pipeline, scheduler)
+  scheduler$reporter$report_pattern(target, scheduler$progress)
 }
 
 pattern_begin_final <- function(target, pipeline, scheduler, meta) {
