@@ -71,14 +71,9 @@ tar_mermaid <- function(
   tar_assert_lgl(color)
   tar_assert_scalar(legend)
   tar_assert_scalar(color)
-  tar_config_assert_reporter_outdated(reporter)
   reporter <- tar_outdated_reporter(reporter)
   tar_assert_callr_function(callr_function)
   tar_assert_list(callr_arguments, "callr_arguments mut be a list.")
-  tar_assert_dbl(seconds_reporter)
-  tar_assert_scalar(seconds_reporter)
-  tar_assert_none_na(seconds_reporter)
-  tar_assert_ge(seconds_reporter, 0)
   targets_arguments <- list(
     path_store = store,
     targets_only = targets_only,
@@ -91,8 +86,7 @@ tar_mermaid <- function(
     label_width = label_width,
     legend = legend,
     color = color,
-    reporter = reporter,
-    seconds_reporter = seconds_reporter
+    reporter = reporter
   )
   callr_outer(
     targets_function = tar_mermaid_inner,
@@ -119,8 +113,7 @@ tar_mermaid_inner <- function(
   label_width,
   legend,
   color,
-  reporter,
-  seconds_reporter
+  reporter
 ) {
   names <- tar_tidyselect_eval(names_quosure, pipeline_get_names(pipeline))
   network <- inspection_init(
@@ -133,8 +126,7 @@ tar_mermaid_inner <- function(
     allow = allow_quosure,
     exclude = exclude_quosure,
     outdated = outdated,
-    reporter = reporter,
-    seconds_reporter = seconds_reporter
+    reporter = reporter
   )
   visual <- mermaid_init(
     network = network,
