@@ -809,7 +809,7 @@ tar_deprecate_seconds_interval <- function(seconds_interval) {
     tar_warn_deprecate(
       "The seconds_interval argument of tar_make() and tar_config_set() ",
       "is deprecated (2023-08-24, version 1.2.2.9001). Instead, use arguments",
-      "seconds_meta_append, seconds_meta_upload, and seconds_reporter."
+      "seconds_meta_append and seconds_meta_upload"
     )
   }
 }
