@@ -12,6 +12,7 @@ tar_test("AWS meta", {
     tar_option_set(
       format = "rds",
       repository = "aws",
+      repository_meta = "aws",
       resources = tar_resources(
         aws = tar_resources_aws(
           bucket = bucket_name,
@@ -29,8 +30,8 @@ tar_test("AWS meta", {
     )
   }, env = list(bucket_name = bucket_name))
   do.call(tar_script, list(code = code))
-  tar_make()
-  expect_true(all(tar_progress()$progress == "built"))
+  tar_make(reporter = "silent")
+  expect_true(all(tar_progress()$progress == "completed"))
   expect_equal(tar_read(c), 2L)
   for (file in c("meta", "process", "progress", "crew")) {
     expect_true(
@@ -52,7 +53,7 @@ tar_test("AWS meta", {
   }
   unlink(path_meta(path_store_default()))
   expect_equal(sort(tar_outdated()), sort(c("a", "b", "c")))
-  tar_make()
+  tar_make(reporter = "silent")
   expect_true(all(tar_progress()$progress == "skipped"))
   tar_destroy()
   for (file in c("meta", "process", "progress", "crew")) {
@@ -89,6 +90,7 @@ tar_test("AWS tar_meta_delete()", {
     tar_option_set(
       format = "rds",
       repository = "aws",
+      repository_meta = "aws",
       resources = tar_resources(
         aws = tar_resources_aws(
           bucket = bucket_name,
@@ -106,8 +108,8 @@ tar_test("AWS tar_meta_delete()", {
     )
   }, env = list(bucket_name = bucket_name))
   do.call(tar_script, list(code = code))
-  tar_make()
-  expect_true(all(tar_progress()$progress == "built"))
+  tar_make(reporter = "silent")
+  expect_true(all(tar_progress()$progress == "completed"))
   expect_equal(tar_read(c), 2L)
   for (file in c("meta", "process", "progress", "crew")) {
     expect_true(
@@ -162,6 +164,7 @@ tar_test("AWS tar_meta_upload()", {
     tar_option_set(
       format = "rds",
       repository = "aws",
+      repository_meta = "aws",
       resources = tar_resources(
         aws = tar_resources_aws(
           bucket = bucket_name,
@@ -179,8 +182,8 @@ tar_test("AWS tar_meta_upload()", {
     )
   }, env = list(bucket_name = bucket_name))
   do.call(tar_script, list(code = code))
-  tar_make()
-  expect_true(all(tar_progress()$progress == "built"))
+  tar_make(reporter = "silent")
+  expect_true(all(tar_progress()$progress == "completed"))
   expect_equal(tar_read(c), 2L)
   for (file in c("meta", "process", "progress", "crew")) {
     expect_true(
@@ -227,6 +230,7 @@ tar_test("AWS tar_meta_download()", {
     tar_option_set(
       format = "rds",
       repository = "aws",
+      repository_meta = "aws",
       resources = tar_resources(
         aws = tar_resources_aws(
           bucket = bucket_name,
@@ -244,8 +248,8 @@ tar_test("AWS tar_meta_download()", {
     )
   }, env = list(bucket_name = bucket_name))
   do.call(tar_script, list(code = code))
-  tar_make()
-  expect_true(all(tar_progress()$progress == "built"))
+  tar_make(reporter = "silent")
+  expect_true(all(tar_progress()$progress == "completed"))
   expect_equal(tar_read(c), 2L)
   for (file in c("meta", "process", "progress", "crew")) {
     expect_true(
@@ -280,6 +284,7 @@ tar_test("AWS tar_meta_sync() upload", {
     tar_option_set(
       format = "rds",
       repository = "aws",
+      repository_meta = "aws",
       resources = tar_resources(
         aws = tar_resources_aws(
           bucket = bucket_name,
@@ -297,8 +302,8 @@ tar_test("AWS tar_meta_sync() upload", {
     )
   }, env = list(bucket_name = bucket_name))
   do.call(tar_script, list(code = code))
-  tar_make()
-  expect_true(all(tar_progress()$progress == "built"))
+  tar_make(reporter = "silent")
+  expect_true(all(tar_progress()$progress == "completed"))
   expect_equal(tar_read(c), 2L)
   for (file in c("meta", "process", "progress", "crew")) {
     expect_true(
@@ -345,6 +350,7 @@ tar_test("AWS tar_meta_sync() download", {
     tar_option_set(
       format = "rds",
       repository = "aws",
+      repository_meta = "aws",
       resources = tar_resources(
         aws = tar_resources_aws(
           bucket = bucket_name,
@@ -362,8 +368,8 @@ tar_test("AWS tar_meta_sync() download", {
     )
   }, env = list(bucket_name = bucket_name))
   do.call(tar_script, list(code = code))
-  tar_make()
-  expect_true(all(tar_progress()$progress == "built"))
+  tar_make(reporter = "silent")
+  expect_true(all(tar_progress()$progress == "completed"))
   expect_equal(tar_read(c), 2L)
   for (file in c("meta", "process", "progress", "crew")) {
     expect_true(
@@ -394,6 +400,7 @@ tar_test("AWS tar_meta_sync() download graceful failure", {
     library(targets)
     tar_option_set(
       repository = "aws",
+      repository_meta = "aws",
       resources = tar_resources(
         aws = tar_resources_aws(
           bucket = bucket_name,
@@ -430,6 +437,7 @@ tar_test("AWS tar_meta_sync() upload graceful failure", {
     library(targets)
     tar_option_set(
       repository = "aws",
+      repository_meta = "aws",
       resources = tar_resources(
         aws = tar_resources_aws(
           bucket = bucket_name,
