@@ -133,7 +133,9 @@ tar_test("target_downstream_branching()", {
   z <- target_init("z", quote(x), pattern = quote(map(x)))
   w <- target_init("w", quote(x), pattern = quote(map(y)))
   pipeline <- pipeline_init(list(x, y, z, w))
-  scheduler <- scheduler_init(pipeline, meta = meta_init())
+  meta <- meta_init()
+  on.exit(meta$database$close())
+  scheduler <- scheduler_init(pipeline, meta = meta)
   expect_equal(target_downstream_branching(x, pipeline, scheduler), "z")
 })
 
@@ -144,7 +146,9 @@ tar_test("target_downstream_nonbranching()", {
   z <- target_init("z", quote(x), pattern = quote(map(x)))
   w <- target_init("w", quote(x), pattern = quote(map(y)))
   pipeline <- pipeline_init(list(x, y, z, w))
-  scheduler <- scheduler_init(pipeline, meta = meta_init())
+  meta <- meta_init()
+  on.exit(meta$database$close())
+  scheduler <- scheduler_init(pipeline, meta = meta)
   out <- target_downstream_nonbranching(x, pipeline, scheduler)
   expect_equal(sort(out), sort(c("w", "y")))
 })
