@@ -17,6 +17,21 @@ tar_test("run verbose reporter with a error and save workspace", {
   expect_error(expect_message(local$run()), class = "tar_condition_run")
 })
 
+tar_test("run verbose reporter workspace upload", {
+  skip_on_os("windows")
+  skip_on_ci()
+  pipeline <- pipeline_init(
+    list(
+      target_init("x", quote(123))
+    )
+  )
+  local <- local_init(pipeline, reporter = "verbose")
+  local$run()
+  expect_message(
+    local$scheduler$reporter$report_workspace_upload(pipeline$targets$x)
+  )
+})
+
 tar_test("run verbose reporter with a warning", {
   pipeline <- pipeline_init(list(target_init("x", quote(warning(123)))))
   local <- local_init(pipeline, reporter = "verbose")
@@ -38,6 +53,11 @@ tar_test("verbose reporter retry message", {
   )
 })
 
+tar_test("report_pattern()", {
+  x <- verbose_new()
+  expect_message(x$report_pattern(tar_target(x, TRUE, pattern = map(y))))
+})
+
 tar_test("validate verbose reporter", {
   expect_silent(reporter_init("verbose")$validate())
 })
